@@ -104,11 +104,18 @@ c     *
 #include "Zobsv.h"
 #include "Zcode.h"
       
+
+
       record /track/incident
       record /coord /angle
 
+
+      integer  EventNo
+      integer i, j
+      integer seed(2)
       real*8 svEasWait, svEthin, kepn
 
+      
       Np = 0
       call cqIncident( incident, angle)
       kepn = incident.p.fm.p(4)
@@ -127,6 +134,21 @@ c     *
 
 c     ===================================================
 
+      EventNo = EventNo + 1     
+      do i = 1, NoOfSites
+         write(*, 1000)
+     *    sngl(ObsSites(i).pos.depth),
+     *    EventNo, 
+     *    incident.p.code,
+     *    incident.p.subcode,
+     *    incident.p.charge, 
+     *    incident.p.fm.e,
+     *    -angle.r(1),
+     *    -angle.r(2),
+     *    -angle.r(3)
+ 1000       format(f10.3,i9,3i4,e15.5,3(1x,f12.8))
+      enddo
+
 
 c     ===================================================
       end
@@ -147,7 +169,8 @@ c
 #include "Zcode.h"
 #include "Ztrack.h"
 #include "Zprivate.h"
-      integer id  ! input.  1 ==> aTrack is going out from
+      integer id  ! input.  2 ==> reached at an observation level
+c                           1 ==> aTrack is going out from
 c                                 outer boundery.
 c                           2 ==> reached at an observation level
 c                           3 ==> reached at inner boundery.
@@ -157,6 +180,9 @@ c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
 c     ===================================================
+      common /testcos/sumg, ng(20), nth, EventNo
+      real*8 sumg
+      integer ng, nth, EventNo
 
 c     ===================================================
       if( id .eq. 2 .and. aTrack.p.code .ne. kneumu .and.
@@ -180,6 +206,19 @@ c     ===================================================
          o(Np).wz =aTrack.vec.w.r(3)
          o(Np).zenith = aTrack.vec.coszenith
 c     ===================================================
+       if( o(Np).code .le. 6 .and. o(Np).code .ne. 3 ) then
+         write(*, 959) 
+     *  o(Np).where,   
+     *  o(Np).code,   
+     *  o(Np).charge,  
+     *  ( o(Np).erg - o(Np).mass ),   
+     *  ( o(Np).x ), ( o(Np).y ) ,  
+     *  ( o(Np).wx ),  
+     *  ( o(Np).wy ),  
+     *  ( o(Np).wz ),  
+     *  ( o(Np).zenith ) 
+ 959    format(3i3,f12.3,2f16.6,4(1x,f12.8))
+      endif
 
 c     ===================================================
       endif
@@ -204,6 +243,7 @@ c    *
 #include "Zprivate.h"
 
       integer i
+      integer seed(2)
       real  sumeg, sumeh
       logical memorize
 
@@ -318,6 +358,7 @@ c
 #include  "Zcode.h"
 c  #include  "Ztrackp.h"
       integer never             ! input & output
+      integer nlow
 c 
 c    If Job = 'newskel', input  "never" may be < 0,  and MovedTrack
 c    may not be an electron.
@@ -359,10 +400,8 @@ c        energy region.
       endif
 
       call cmemoNode(Wdev, never)
-      
       if(MovedTrack.asflag .eq. -1) then
-c            af flesh time, decendent should not be used to
-c            generae A.S
+c          decendent should not be used to  generae A.S
          MovedTrack.asflag  = -2
       endif
 
@@ -466,7 +505,7 @@ c       radiallen: can be computed from height
 c         vec; children knows  their direction
 c         wgt: normally not needed, it should be 1 for skeleton making
 c              So thinsamping must not be used when making skeleton.
-c      asflab: should be always F, (assume for skeleton making, hybrid
+c      asflag: should be always F, (assume for skeleton making, hybrid
 c              air shower is not requested)       
 c
 c   write  track info. of projectile
@@ -494,8 +533,15 @@ c               all ptcl must be memorized
             endif
          endif
       enddo
+c         next is harmful for B-approx air shower
+c         because, parent is not memorized and cannot
+c         generate AS at flesh time at proper positon
+c         asflag == -1 must apear in flesh
+c      if(nlow .eq. 0 )  return !  *************
+c       if there is no return here, the size of skeleton data
+c       becomes 3.2 times larger
+      if(nlow .eq. 0  .and. MovedTrack.asflag .ne. -1) return
 
-      if(nlow .eq. 0 )  return !  *************
 
       p.posx = MovedTrack.pos.xyz.r(1)
       p.posy = MovedTrack.pos.xyz.r(2)
