@@ -56,11 +56,13 @@ c            restore Job
          Job = temp
       endif
 
-c        reset parameters.
+c        reset parameters
       if(BorderHeightH .eq. 0.0) then
          BorderHeightH = HeightOfInj + 1.0d0    ! from v6.10
       endif
-
+c////////////
+      write(0, *) ' BorderHeightH=',BorderHeightH 
+c/////////////
       EventsInTheRun = 0      ! moved from ciniTracking0. 2001.09/30
 
       if(DestEventNo(2) .eq. 0) then
@@ -84,6 +86,11 @@ c          read segmented atmosphere data
 c          manipulate data
       call catmosCnst1
       call catmosCnst2
+#elif ATMOSPHERE == 2
+c          read segmented atmosphere data
+      call creadAtmosD
+c          manipulate data
+      call catmosCnst1
 #endif
 c         init for geomag
       call crdGeomag(GeomagFile, YearOfGeomag)
@@ -113,13 +120,15 @@ c           init for knockon process; Knockon is not used now.
 c              ********* Knockon is not used now ******
          if(Job .eq. 'newskel') then
             call cdedxEleci(KEminObs*KnockOnRatio, Knockon)
-         else
+         elseif(KEminObs2*KnockOnRatio .gt. 0.) then
 c                 this must come after cwhatJob, since KEminObs2 must
 c           be fixed.  For skeleton-flesh job, KnockOnRatio should be
 c           small enough so that KEminObs2*KnockOnRatio < KEminObs at
 c           flesh time  
 
             call cdedxEleci(KEminObs2*KnockOnRatio, Knockon)
+         else
+            call cerrorMsg('KnockOnRatio<1 and others mismatch', 0)
          endif
       else
          call cdedxEleci(RecoilKineMinE, Knockon)
@@ -145,24 +154,9 @@ c         user hook
 #include  "Zheavyv.h"
 
 c
-      character*24 hostn
-      integer leng,  j
+
       integer i, now(2)
-#if defined Solaris
-      integer time
-#elif defined PCLinuxIFC
-      integer hour, mint, sec, hsec
-#endif
-
 c  
-c      ********** 
-c      next  is a "directive" for absoft f90.
-c      which is to make the call TIME as if call time.
-c      For absoft f90 ; we have to treat all variable in upper case
-c      but there is no TIME tourine in the system.
-c
-cdir$ NAME (TIME="time")
-
 c
 c
       ObserveAS = index(Generate, 'as')  .gt. 0 .or.
@@ -182,28 +176,7 @@ c
          call rnd1r(InitRN)     ! init randeom number generator
 c      *****************
       elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
-#if defined Solaris
-         now(1)= time()
-#elif defined PCLinuxIFC
-         call gettim(hour, mint, sec, hsec)
-         now(1) = hsec
-         now(2) = sec
-#else
-         call time(now)
-#endif
-
-c         now(2) =-InitRN(2)  !  2001.09.30; dec fortran changes now(2).
-c
-c         add a max of 4 last char. of hostname after converting to int.
-
-         call cgetHost(leng, hostn)   ! get hostname
-         i = max(1, leng-3)
-
-         do  j = i, leng
-            now(2) = now(2) + ichar( hostn(j:j) )
-            now(1) = now(1) + ichar( hostn(j:j) )
-         enddo
-
+         call cmkSeed(0, now)   ! make seed using timer and hostname
          call rnd1r(now)
 c     ******************
       endif
