@@ -274,20 +274,13 @@ c     **********************************
       rho = cvh2den(
      *      (TrackBefMove.pos.height+MovedTrack.pos.height)/2.d0
      *      )
-      leng = IntInfArray(ProcessNo).length  ! in m
-c///////////
-      if(leng .lt. 0.) then
-          write(*,*) ' process=',IntInfArray(ProcessNo).process
-       endif
-c////////////
 
-c /////
-c      if( MovedTrack.p.code .eq. kmuon) then
-c         write(*,*) ' ***',rho, TargetAtomicN, TargetZ2,
-c     *    TargetMassN, MovedTrack.p.charge, MovedTrack.p.mass,
-c     *    g1, g2, leng
-c      endif
-c //////
+      leng = IntInfArray(ProcessNo).length  ! in m
+      if( leng .lt. 0.) then
+         call cerrorMsg('leng < 0 in cmulScat', 1)
+         leng = 1.1d-2
+      endif
+
       chg =  MovedTrack.p.charge
       call cmoliere(rho, TargetAtomicN, TargetZ2, TargetMassN,
      *   chg, MovedTrack.p.mass, g1, g2,  leng, teta, cond)
