@@ -69,8 +69,8 @@ c               convert coord.
       record /coord/  f, t
 
       real*8  xxx/-1.d37/, yyy/-1.d36/, zzz/1.d34/
-      integer kkk/-1000/
-      save xxx, yyy, zzz, kkk
+      integer kkk/-1000/, chg/-1000/
+      save xxx, yyy, zzz, kkk, chg
       logical compress
       
       if(.not. compress) then
@@ -84,7 +84,8 @@ c               convert coord.
          write(TraceDev, *)
       else
          if(kkk .ne. MovedTrack.p.code .or. f.r(1) .ne. xxx
-     *    .or. f.r(2) .ne. yyy .or. f.r(3) .ne. zzz) then
+     *    .or. f.r(2) .ne. yyy .or. f.r(3) .ne. zzz  .or.
+     *     chg .ne. MovedTrack.p.charge ) then
             if(xxx .ne. -1.d37) then
                write(TraceDev, *) 
                write(TraceDev, *) 
@@ -92,14 +93,21 @@ c               convert coord.
             write(TraceDev, *) sngl(f.r(1)), sngl(f.r(2)), sngl(f.r(3)), 
      *      TrackBefMove.p.code, sngl(TrackBefMove.p.fm.p(4)),
      *      TrackBefMove.p.charge
+c^^^^^^^
+c     *      ,sngl( TrackBefMove.t/3.e8)
+c^^^^^^^
          endif
          write(TraceDev, *) sngl(t.r(1)), sngl(t.r(2)), sngl(t.r(3)), 
      *     MovedTrack.p.code, sngl(MovedTrack.p.fm.p(4)),
      *     MovedTrack.p.charge
+c^^^^^^^
+c     *    , sngl(MovedTrack.t/3.e8)
+c^^^^^^^^
          xxx = t.r(1)
          yyy = t.r(2)
          zzz = t.r(3)
          kkk = MovedTrack.p.code
+         chg = MovedTrack.p.charge
       endif
       end
 c     ***************************************
